#!/usr/bin/env python
#!/usr/bin/python2.5
import sys 
import dbus
from PyQt4 import QtGui,QtCore
from Kall_ui import *

class MainWindow(QtGui.QMainWindow):
        def __init__(self, parent=None):
                #build parent user interface
                QtGui.QWidget.__init__(self, parent)
                self.ui = Ui_MainWindow()
                self.ui.setupUi(self)
		self.timer = QtCore.QTimer()
		QtCore.QObject.connect(self.ui.btn1, QtCore.SIGNAL('clicked()'), self.add1)
		QtCore.QObject.connect(self.ui.btn2, QtCore.SIGNAL('clicked()'), self.add2)
		QtCore.QObject.connect(self.ui.btn3, QtCore.SIGNAL('clicked()'), self.add3)
		QtCore.QObject.connect(self.ui.btn4, QtCore.SIGNAL('clicked()'), self.add4)
		QtCore.QObject.connect(self.ui.btn5, QtCore.SIGNAL('clicked()'), self.add5)
		QtCore.QObject.connect(self.ui.btn6, QtCore.SIGNAL('clicked()'), self.add6)
		QtCore.QObject.connect(self.ui.btn7, QtCore.SIGNAL('clicked()'), self.add7)
		QtCore.QObject.connect(self.ui.btn8, QtCore.SIGNAL('clicked()'), self.add8)
		QtCore.QObject.connect(self.ui.btn9, QtCore.SIGNAL('clicked()'), self.add9)
		QtCore.QObject.connect(self.ui.btn0, QtCore.SIGNAL('clicked()'), self.add0)
		QtCore.QObject.connect(self.ui.btnA, QtCore.SIGNAL('clicked()'), self.addA)
		QtCore.QObject.connect(self.ui.btnN, QtCore.SIGNAL('clicked()'), self.addN)
		QtCore.QObject.connect(self.ui.btnClear, QtCore.SIGNAL('clicked()'), self.clear)
		QtCore.QObject.connect(self.ui.btnT58, QtCore.SIGNAL('clicked()'), self.addT58)
		QtCore.QObject.connect(self.ui.btnT298, QtCore.SIGNAL('clicked()'), self.addT298)
		QtCore.QObject.connect(self.ui.btnKall, QtCore.SIGNAL('clicked()'), self.kall)
		
	def add1(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"1") 
		
	def add2(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"2") 
			
	def add3(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"3")
			
	def add4(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"4")
			
	def add5(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"5")
			
	def add6(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"6")
			
	def add7(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"7")
			
	def add8(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"8")
			
	def add9(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"9")
			
	def add0(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"0")
			
	def addN(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"#")
			
	def addA(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text()+"*")
			
	def clear(self):
			self.ui.edtPhone.setText(self.ui.edtPhone.text().mid(0,self.ui.edtPhone.text().count()-1))
			
	def addT58(self):
			self.ui.spnSec.setValue(58)
			
	def addT298(self):
			self.ui.spnSec.setValue(298)
	def kall(self):
			if (self.ui.edtPhone.text().isEmpty()):
				bus = dbus.SystemBus()
				iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
                                        '/org/freedesktop/Notifications'),
                                        'org.freedesktop.Notifications')
				iface.SystemNoteInfoprint("Can't Kall with an empty phone number!")
			else:
				bus = dbus.SystemBus()
				csd_call = dbus.Interface(bus.get_object('com.nokia.csd',
                                           '/com/nokia/csd/call'),
                                           'com.nokia.csd.Call')
				csd_call.CreateWith(str(self.ui.edtPhone.text()), dbus.UInt32(0))
				self.single()
			
	def single(self):
		self.timer.singleShot(self.ui.spnSec.value()*1000, self.hangUp)	
	
	def hangUp(self):
		bus = dbus.SystemBus()
		csd_call = dbus.Interface(bus.get_object('com.nokia.csd',
                                           '/com/nokia/csd/call'),
                                           'com.nokia.csd.Call')
		csd_call.Release()
		if self.ui.chkRedial.isChecked():
				csd_call = dbus.Interface(bus.get_object('com.nokia.csd',
                                           '/com/nokia/csd/call'),
                                           'com.nokia.csd.Call')
				csd_call.CreateWith(str(self.ui.edtPhone.text()), dbus.UInt32(0))
				self.single()
				iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
                                        '/org/freedesktop/Notifications'),
                                        'org.freedesktop.Notifications')
				iface.SystemNoteInfoprint("Redialing..")
			
if __name__ == "__main__":
        #This function means this was run directly, not called from another python file.
        app = QtGui.QApplication(sys.argv)
        myapp = MainWindow()
        myapp.show()
        sys.exit(app.exec_())